@@ -18,11 +18,11 @@ from bcf.utils import *
 import bcf.firmware.utils as futils
 
 
-__version__ = '1.5.2'
-SDK_URL_ZIP = 'https://codeload.github.com/bigclownlabs/bcf-sdk/zip/master'
-SDK_GIT = 'https://github.com/bigclownlabs/bcf-sdk.git'
-VSCODE_GIT = 'https://github.com/bigclownlabs/bcf-vscode.git'
-VSCODE_URL_ZIP = 'https://codeload.github.com/bigclownlabs/bcf-vscode/zip/master'
+__version__ = '1.7.0'
+SDK_URL_ZIP = 'https://codeload.github.com/hardwario/bcf-sdk/zip/master'
+SDK_GIT = 'https://github.com/hardwario/bcf-sdk.git'
+VSCODE_GIT = 'https://github.com/hardwario/bcf-vscode.git'
+VSCODE_URL_ZIP = 'https://codeload.github.com/hardwario/bcf-vscode/zip/master'
 
 
 @click.group()
@@ -55,8 +55,9 @@ def _create_get_firmware_list(ctx, args, incomplete):
 @cli.command('create')
 @click.argument('name')
 @click.option('--no-git', is_flag=True, help='Disable git.')
-@click.option('--from', '_from', help='Disable git.', default='bigclownlabs/bcf-skeleton', autocompletion=_create_get_firmware_list)
-def command_create(name, no_git, _from):
+@click.option('--from', '_from', help='Disable git.', default='hardwario/bcf-skeleton', autocompletion=_create_get_firmware_list)
+@click.option('--depth', 'depth', help='Set git submodule clone depth.')
+def command_create(name, no_git, _from, depth):
     '''Create new firmware.'''
 
     if os.path.exists(name):
@@ -65,8 +66,8 @@ def command_create(name, no_git, _from):
 
     _from = _from.rstrip('/')
 
-    if _from == 'bigclownlabs/bcf-skeleton':
-        repository = 'https://github.com/bigclownlabs/bcf-skeleton'
+    if _from == 'hardwario/bcf-skeleton':
+        repository = 'https://github.com/hardwario/bcf-skeleton'
     elif re.match('^https://github.com/[^/]+/[^/]+$', _from):
         repository = _from
     else:
@@ -113,8 +114,9 @@ def command_create(name, no_git, _from):
 
     else:
         os.system('git init')
-        os.system('git submodule add --depth 1 "' + SDK_GIT + '" sdk')
-        os.system('git submodule add --depth 1 "' + VSCODE_GIT + '" .vscode')
+        depth = '' if not depth else ' --depth ' + str(depth)
+        os.system('git submodule add' + depth + ' "' + SDK_GIT + '" sdk')
+        os.system('git submodule add' + depth + ' "' + VSCODE_GIT + '" .vscode')
 
     os.rmdir(tmp_dir)
 
